@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # --------------------------------------------------------------------
 # Copyright (c) iEXBase. All rights reserved.
 # Licensed under the MIT License.
@@ -27,7 +28,7 @@ from tronpytool.common.abi import (
     abi_to_signature,
     fallback_func_abi_exists,
     check_if_arguments_can_be_encoded,
-    map_abi_data
+    map_abi_data, filter_by_name
 )
 from tronpytool.common.contracts import (
     find_matching_fn_abi,
@@ -116,34 +117,47 @@ class ContractFunction:
         return '<Function %s>' % self.fn_name
 
 
-
-
 class ContractFunctions:
     """
     Class containing contract function objects
     """
 
-    def __init__(self, abi, tron, address=None):
-        if abi:
-            self.abi = abi
-            self._functions = filter_by_type('function', self.abi)
+    def __init__(self, _abi, tron, address=None):
+        if _abi:
+            self._functions = filter_by_type('function', _abi)
             for func in self._functions:
-                setattr(
-                    self,
-                    func['name'],
-                    ContractFunction.factory(
-                        func['name'],
-                        tron=tron,
-                        contract_abi=self.abi,
-                        address=address,
-                        function_identifier=func['name']))
+                setattr(self, func['name'],
+                        ContractFunction.factory(
+                            func['name'],
+                            tron=tron,
+                            contract_abi=_abi,
+                            address=address,
+                            function_identifier=func['name']))
+            self.abi = _abi
+
+    def get_abi_by_name(self, func_name: str) -> dict:
+        """Find the correct function abi for the name"""
+        t = filter_by_name(func_name, self.abi)
+        if len(t) > 0:
+            return t[0]
+        raise NoABIFunctionsFound(
+            "The abi for this contract contains no function definitions. ",
+            "Are you sure you provided the correct call name from the abi?"
+        )
 
     def print_functions(self):
-        print("=========")
-        print(self.abi)
-        print("=========")
+        """only for testing, list all the functions that can be called. """
         for func in self._functions:
-            print(func['name'])
+            if func['type'] == 'function':
+                if func['stateMutability'] in ['pure', 'view']:
+                    printdebugfunc('read', func)
+                if func['stateMutability'] in ['nonpayable']:
+                    printdebugfunc('write', func)
+
+            if func['type'] == 'constructor':
+                printdebugfunc('constructor', func)
+            print("=====")
+            print(func)
 
     def __iter__(self):
         if not hasattr(self, '_functions') or not self._functions:
@@ -207,7 +221,7 @@ class Contract:
         self.fallback = Contract.get_fallback_function(self.abi, self.tron, self.address)
 
     @classmethod
-    def factory(cls, tron, class_name=None, **kwargs) -> PropertyCheckingFactory:
+    def factory(cls, tron: any, class_name=None, **kwargs) -> "PropertyCheckingFactory":
 
         kwargs['tron'] = tron
         normalizers = {
@@ -424,3 +438,22 @@ def get_function_by_identifier(fns, identifier):
             'Could not find any function with matching {0}'.format(identifier)
         )
     return fns[0]
+
+
+def printdebugfunc(typecontrol, func):
+    b = "{} {}({}) {}"
+    input_space = ""
+    oput_space = ""
+
+    try:
+        input_space = func['input']
+    except KeyError:
+        pass
+
+    try:
+        oput_space = "-> {}".format(func['output'])
+    except KeyError:
+        pass
+
+    print(b.format(typecontrol, func['name'], input_space, oput_space))
+    print("=====")
