@@ -34,7 +34,7 @@ from trx_utils import (
     to_hex
 )
 
-from tronpytool import HttpProvider, constants
+from tronpytool import constants
 from tronpytool.common.abi import map_abi_data
 from tronpytool.common.account import Address, PrivateKey, Account
 from tronpytool.common.encoding import (
@@ -61,7 +61,7 @@ DEFAULT_MODULES = {
 
 class Tron:
     # Providers
-    HTTPProvider = HttpProvider
+    # SolcWrap = SolcWrap
 
     _default_block = None
     _private_key = None
@@ -125,11 +125,7 @@ class Tron:
 
     def setNetwork(self, networkname="nile"):
         group = constants.conf_for_name(networkname)
-        self.manager = TronManager(self, dict(
-            full_node=HttpProvider(group["full_node"]),
-            solidity_node=HttpProvider(group["solidity_node"]),
-            event_server=HttpProvider(group["event_server"])
-        ))
+        self.manager = TronManager(self, constants.to_providers_set(group))
         return self
 
     @property
@@ -154,10 +150,14 @@ class Tron:
         return self.manager.providers
 
     @property
-    def private_key(self):
+    def private_key(self) -> str:
         """Get a private key"""
         return self._private_key
 
+    def getKey(self) -> "PrivateKey":
+        return self.private_key_class
+
+
     @private_key.setter
     def private_key(self, value: str) -> None:
         """Set a private key used with the TronAPI instance,
@@ -170,7 +170,7 @@ class Tron:
             private_key = PrivateKey(value)
         except ValueError:
             raise TronError('Invalid private key provided')
-
+        self.private_key_class = private_key
         self._private_key = str(private_key).lower()
 
     @property
@@ -295,7 +295,7 @@ class Tron:
         Note:
             If you wish to convert generic data to hexadecimal strings,
             please use the function tron.to_hex.
-
+            return a static class
         """
         return Address()
 
@@ -328,15 +328,6 @@ class Tron:
         """
         return Account.create()
 
-    @staticmethod
-    def is_valid_provider(provider) -> bool:
-        """Check connected provider
-
-        Args:
-            provider(HttpProvider): Provider
-        """
-        return isinstance(provider, HttpProvider)
-
     def solidity_sha3(self, abi_types, values):
         """
             Executes keccak256 exactly as Solidity does.
